@@ -13,10 +13,11 @@ print.hmmseg<-function(x,...){
   cat("Keep Symbols    :  ");cat(x$symbol);cat("\n")
   cat("Output Path     :  ");cat(x$output);cat("\n")
   cat("Write File      :  ");cat(x$write);cat("\n")
+  cat("By Lines        :  ");cat(x$bylines);cat("\n")
   cat("Max Read Lines  :  ");cat(x$lines);cat("\n");cat("\n")
   cat("Fixed Model Components:  ");cat("\n");cat("\n")
   print(x$PrivateVarible)
-  cat("$detect $encoding $symbol $output $write $lines can be reset.\n")
+  cat("$detect $encoding $symbol $output $write $lines $bylines can be reset.\n")
 }
 
 #' @rdname print.hmmseg
@@ -28,10 +29,11 @@ print.queryseg<-function(x,...){
   cat("Keep Symbols    :  ");cat(x$symbol);cat("\n")
   cat("Output Path     :  ");cat(x$output);cat("\n")
   cat("Write File      :  ");cat(x$write);cat("\n")
+  cat("By Lines        :  ");cat(x$bylines);cat("\n")
   cat("Max Read Lines  :  ");cat(x$lines);cat("\n");cat("\n")
   cat("Fixed Model Components:  ");cat("\n");cat("\n")
   print(x$PrivateVarible)
-  cat("$detect $encoding $symbol $output $write $lines can be reset.\n")
+  cat("$detect $encoding $symbol $output $write $lines $bylines can be reset.\n")
 }
 
 #' @rdname print.hmmseg
@@ -68,10 +70,11 @@ print.tagger<-function(x,...){
   cat("Keep Symbols    :  ");cat(x$symbol);cat("\n")
   cat("Output Path     :  ");cat(x$output);cat("\n")
   cat("Write File      :  ");cat(x$write);cat("\n")
+  cat("By Lines        :  ");cat(x$bylines);cat("\n")
   cat("Max Read Lines  :  ");cat(x$lines);cat("\n");cat("\n")
   cat("Fixed Model Components:  ");cat("\n");cat("\n")
   print(x$PrivateVarible)
-  cat("$detect $encoding $symbol $output $write $lines can be reset.\n")
+  cat("$detect $encoding $symbol $output $write $lines $bylines can be reset.\n")
 }
 
 #' @rdname print.hmmseg
@@ -83,10 +86,11 @@ print.mixseg<-function(x,...){
   cat("Keep Symbols    :  ");cat(x$symbol);cat("\n")
   cat("Output Path     :  ");cat(x$output);cat("\n")
   cat("Write File      :  ");cat(x$write);cat("\n")
+  cat("By Lines        :  ");cat(x$bylines);cat("\n")
   cat("Max Read Lines  :  ");cat(x$lines);cat("\n");cat("\n")
   cat("Fixed Model Components:  ");cat("\n");cat("\n")
   print(x$PrivateVarible)
-  cat("$detect $encoding $symbol $output $write $lines can be reset.\n")
+  cat("$detect $encoding $symbol $output $write $lines $bylines can be reset.\n")
 }
 
 #' @rdname print.hmmseg
@@ -98,10 +102,11 @@ print.mpseg<-function(x,...){
   cat("Keep Symbols    :  ");cat(x$symbol);cat("\n")
   cat("Output Path     :  ");cat(x$output);cat("\n")
   cat("Write File      :  ");cat(x$write);cat("\n")
+  cat("By Lines        :  ");cat(x$bylines);cat("\n")
   cat("Max Read Lines  :  ");cat(x$lines);cat("\n");cat("\n")
   cat("Fixed Model Components:  ");cat("\n");cat("\n")
   print(x$PrivateVarible)
-  cat("$detect $encoding $symbol $output $write $lines can be reset.\n")
+  cat("$detect $encoding $symbol $output $write $lines $bylines can be reset.\n")
 }
 
 #' @export
